@@ -1,6 +1,7 @@
 from pymatgen.io.vasp.sets import DictSet, _load_yaml_config
 from pymatgen.core.structure import Structure
 from atomate.vasp.workflows.base.core import get_wf
+from atomate.vasp.fireworks.core import StaticFW, NonSCFFW
 from atomate.vasp.powerups import add_small_gap_multiply, add_stability_check, add_modify_incar, \
     add_wf_metadata, add_common_powerups
 from quantumML.fireworks import OptimizeFW2D
@@ -132,13 +133,19 @@ def wf_bandstructure2D(structure, c=None):
     db_file = c.get("DB_FILE", DB_FILE)
     vdw_kernel = c.get("VDW_KERNEL_DIR", VDW_KERNEL_DIR)
 
-    mpr2d = MPScanRelaxSet2D(structure, force_gamma=True, potcar_functional='PBE')
+    mpr2d = MPScanRelaxSet2D(structure, force_gamma=True, potcar_functional='PBE_52')
+    fws = [OptimizeFW2D(structure=structure, vasp_input_set=mpr2d, vasp_cmd=vasp_cmd, db_file=db_file, vdw_kernel_dir=vdw_kernel)]
+    fws.append(StaticFW(parents=fws[0]))
+    fws.append(NonSCFFW(parents=fws[1], mode='uniform'))
+    fws.append(NonSCFFW(parents=fws[1], mode='line'))
+    wf = Workflow(fws)
     '''check bandstructure.yaml'''
-    wf = get_wf(structure, "bandstructure.yaml", vis=MPScanRelaxSet2D(structure, force_gamma=True, potcar_functional='PBE'), \
+    '''
+    wf = get_wf(structure, "bandstructure.yaml", vis=MPScanRelaxSet2D(structure, force_gamma=True,), \
                 params=[{'vasp_input_set': mpr2d},{},{},{}], common_params={"vasp_cmd": vasp_cmd, "db_file": db_file,}) #"vdw_kernel_dir": vdw_kernel})
 
     wf = add_common_powerups(wf, c)
-
+    '''
     if c.get("SMALLGAP_KPOINT_MULTIPLY", SMALLGAP_KPOINT_MULTIPLY):
         wf = add_small_gap_multiply(wf, 0.5, 5, "static")
         wf = add_small_gap_multiply(wf, 0.5, 5, "nscf")
@@ -148,10 +155,11 @@ def wf_bandstructure2D(structure, c=None):
 
     if c.get("ADD_WF_METADATA", ADD_WF_METADATA):
         wf = add_wf_metadata(wf, structure)
-    new_firework = OptimizeFW2D(structure=structure, vasp_input_set= mpr2d, vasp_cmd=vasp_cmd, db_file=db_file, vdw_kernel_dir=vdw_kernel)
+
     print(wf)
+    '''
     fws = wf.fws
     fws[0] = new_firework
     print(fws)
-    wf = Workflow(fws)
+    '''
     return wf
\ No newline at end of file
